HotExports | depok test

# HOT Exports

# Job depok test

depok test area

## Runs

State | Download | Created At
--- | --- | ---
| job log file (log.txt) [31.7KB] ESRI Shapefile (zipped) [24.6MB] Spatiallite file [51.2MB] PostGIS dump file (.sql) [88.6MB] SQLite file [67.1MB] OSM source file (.pbf) [8.3MB] | 2013-02-05 05:37

## Area

Min. Longitude | 106.35933252
Min. Latitude | -6.62957885267
Max. Longitude | 107.183160645
Max. Latitude | -5.97051635267

## Tags

The job is based upon the preset file Presets from Mapping Jakarta (2013-02-02 07:35).

Create a new job with a new area but the same tags as this job.